####################################################################
#                                                                  #
#  Windows makefile (Intel Fortran)                                #
#                                                                  #
#  LAPACK make include file.                                       #
#  LAPACK, Version 3.2.1                                           #
#                                                                  #
#  Written by David Svoboda <svoboda@fi.muni.cz> 2009              #
####################################################################

#
#  Change the type of library (comment/uncomment) you want to build
#

SHARED = Yes 

#
#  Choose the version of library (comment/uncomment) you want to build
#

# DEBUG = Yes

#
#  Select which type of system libraries you want to link against
#  - statically linked -> "MT" switch is used
#  - dynamically loaded -> "MD" switch is used
#
 
SYS_LIBS_FLAG = MT

#
#  Modify the FORTRAN and OPTS definitions to refer to the
#  compiler and desired compiler options for your machine.  NOOPT
#  refers to the compiler options desired when NO OPTIMIZATION is
#  selected.  Define LOADER and LOADOPTS to refer to the loader and 
#  desired load options for your machine.
#

FFLAGS = /nologo /names:lowercase /us
FORTRAN  = ifort
OPTS     = /optimize:2 $(FFLAGS) 
DRVOPTS  = $(OPTS)
NOOPT    = /optimize:0 $(FFLAGS)
LOADER   = $(FORTRAN)
LOADOPTS = /nologo

#
# Timer for the SECOND and DSECND routines
#

TIMER = INT_CPU_TIME

#
#  Location of the extended-precision BLAS (XBLAS) Fortran library
#  used for building and testing extended-precision routines.  The
#  relevant routines will be compiled and XBLAS will be linked only if
#  USEXBLAS is defined.
#

# USEXBLAS = Yes
# XBLASLIB = xblas.lib

#
#  The name of the libraries to which you will link.  (The 
#  machine-specific, optimized BLAS library should be used whenever
#  possible.)
#

!ifdef DEBUG
DEBUG_FLAG = d
DEBUG_OPTION = /debug
!else
DEBUG_OPTION = /nodebug
!endif

PLATFORM = win32

BLASNAME     = blas_$(PLATFORM)_$(SYS_LIBS_FLAG)$(DEBUG_FLAG)
LAPACKNAME   = lapack_$(PLATFORM)_$(SYS_LIBS_FLAG)$(DEBUG_FLAG)
TMGNAME      = tmglib_$(PLATFORM)_$(SYS_LIBS_FLAG)$(DEBUG_FLAG)
EIGSRCNAME   = eigsrc_$(PLATFORM)_$(SYS_LIBS_FLAG)$(DEBUG_FLAG)
LINSRCNAME   = linsrc_$(PLATFORM)_$(SYS_LIBS_FLAG)$(DEBUG_FLAG)
	
#
# selection of linking mode (static/shared)
#

LINKER = xilink
LINKERFLAGS = /dll /nologo

LIBRARIAN = xilib
LIBFLAGS = /nologo


!ifdef SHARED
FFLAGS = $(FFLAGS) $(DEBUG_OPTION) /$(SYS_LIBS_FLAG)$(DEBUG_FLAG)
ARCH = $(LINKER)
ARCHFLAGS = $(LINKERFLAGS)
!else 
FFLAGS = $(FFLAGS) $(DEBUG_OPTION) /$(SYS_LIBS_FLAG)$(DEBUG_FLAG)
ARCH = $(LIBRARIAN)
ARCHFLAGS = $(LIBFLAGS)
!endif

# end of file
